@@ -24,7 +24,9 @@ class FileName:
     @staticmethod
     def parse(filename: str) -> 'FileName':
         # some participants use `#` as the seperator while others use `_`. Allow for both here.
-        matches = re.match("NEM[_#]NBCHARGES[_#]([A-Z]+)[_#]([A-Z]+)[_#]([0-9]{14})V([0-9]+)", filename)
+        # some participants use lowercase, `(?i)` makes the regex case insensitive
+        # some participants drop the `v[0-9]` on the end, make it optional as we don't use it anyway
+        matches = re.match("(?i)NEM[_#]NBCHARGES[_#]([A-Z]+)[_#]([A-Z]+)[_#]([0-9]{14})V?([0-9]+)?", filename)
         distributor_mapping = {
             "ENERGEXP": "qld",
             "ERGONETP": "qld",
@@ -39,13 +41,13 @@ class FileName:
             "UNITED": "vic",
             "EASTERN": "vic",
         }
-        if matches is not None and matches.group(1) in distributor_mapping.keys():
+        if matches is not None and matches.group(1).upper() in distributor_mapping.keys():
             return FileName(
-                distributor=matches.group(1),
-                retailer=matches.group(2),
+                distributor=matches.group(1).upper(),
+                retailer=matches.group(2).upper(),
                 timestamp=datetime.datetime.strptime(matches.group(3), "%Y%m%d%H%M%S"),
                 version=int(matches.group(4)),
-                state=distributor_mapping[matches.group(1)]
+                state=distributor_mapping[matches.group(1).upper()]
             )
         else:
             raise base.InvalidFilename("File name {} did not match the expected format".format(filename))
